nfc_device_get_name

Function nfc_device_get_name 

pub unsafe extern "C" fn nfc_device_get_name(
    instance: *const NfcDevice,
    name_type: NfcDeviceNameType,
) -> *const c_char
Get the name of an NfcDevice instance.

The return value may change depending on the instance’s internal state and the name_type parameter.

Arguments

  • instance (direction in) - pointer to the instance to be queried.
  • name_type (direction in) - type of the name to be displayed.

Returns

pointer to a statically allocated string containing the device name.