#[repr(transparent)]pub struct FuriHalSerialDataBits(pub c_uchar);Expand description
Actual data bits, i.e. not including start/stop and parity bits
Note: 6 data bits are only permitted when parity is enabled Note: 9 data bits are only permitted when parity is disabled
Tuple Fields
0: c_ucharTrait Implementations
Sourceimpl Clone for FuriHalSerialDataBits
impl Clone for FuriHalSerialDataBits
Sourcefn clone(&self) -> FuriHalSerialDataBits
fn clone(&self) -> FuriHalSerialDataBits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FuriHalSerialDataBits
Sourceimpl Debug for FuriHalSerialDataBits
impl Debug for FuriHalSerialDataBits
impl Eq for FuriHalSerialDataBits
Sourceimpl Hash for FuriHalSerialDataBits
impl Hash for FuriHalSerialDataBits
Sourceimpl PartialEq for FuriHalSerialDataBits
impl PartialEq for FuriHalSerialDataBits
Sourcefn eq(&self, other: &FuriHalSerialDataBits) -> bool
fn eq(&self, other: &FuriHalSerialDataBits) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FuriHalSerialDataBits