#[repr(transparent)]pub struct NfcCommand(pub c_uchar);Expand description
Enumeration of possible Nfc commands.
The event callback must return one of these to determine the next action.
Tuple Fields
0: c_ucharTrait Implementations
Sourceimpl Clone for NfcCommand
impl Clone for NfcCommand
Sourcefn clone(&self) -> NfcCommand
fn clone(&self) -> NfcCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NfcCommand
Sourceimpl Debug for NfcCommand
impl Debug for NfcCommand
impl Eq for NfcCommand
Sourceimpl Hash for NfcCommand
impl Hash for NfcCommand
Sourceimpl PartialEq for NfcCommand
impl PartialEq for NfcCommand
Sourcefn eq(&self, other: &NfcCommand) -> bool
fn eq(&self, other: &NfcCommand) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NfcCommand