pub unsafe extern "C" fn button_panel_add_item(
button_panel: *mut ButtonPanel,
index: u32,
matrix_place_x: u16,
matrix_place_y: u16,
x: u16,
y: u16,
icon_name: *const Icon,
icon_name_selected: *const Icon,
callback: ButtonItemCallback,
callback_context: *mut c_void,
)Expand description
Add item to button_panel module.
Have to set element in bounds of allocated size by X and by Y.
Arguments
button_panel- ButtonPanel instanceindex- value to pass to callbackmatrix_place_x- coordinates by x-axis on virtual grid, it is only used for navigationmatrix_place_y- coordinates by y-axis on virtual grid, it is only used for naviagationx- x-coordinate to draw icon ony- y-coordinate to draw icon onicon_name- name of the icon to drawicon_name_selected- name of the icon to draw when current element is selectedcallback- function to call when specific element is selected (pressed Ok on selected item)callback_context- context to pass to callback