pub unsafe extern "C" fn onewire_slave_set_reset_callback(
bus: *mut OneWireSlave,
callback: OneWireSlaveResetCallback,
context: *mut c_void,
)Expand description
Set a callback function to be called on each reset. The return value of the callback determines whether the emulated device supports the short reset (passed as the is_short parameter). In most applications, it should also call onewire_slave_set_overdrive() to set the appropriate speed mode.
Arguments
[in]- bus pointer to OneWireSlave instance[in]- callback pointer to a callback function[in]- context additional parameter to be passed to the callback