Function pipe_spaces_available
Source pub unsafe extern "C" fn pipe_spaces_available(
pipe: *mut PipeSide,
) -> usize
Determines how many space there is in the pipe for data to be written
into.
Arguments
[in] - pipe Pipe side to query
Returns
Number of bytes available to be written into that side of the pipe