pub unsafe extern "C" fn storage_file_seek(
file: *mut File,
offset: u32,
from_start: bool,
) -> boolExpand description
Change the current access position in a file.
Arguments
file- pointer to the file instance in question.offset- access position offset (meaning depends on from_start parameter).from_start- if true, set the access position relative to the file start, otherwise relative to the current position.
Returns
success flag