Function storage_int_backup
Source pub unsafe extern "C" fn storage_int_backup(
storage: *mut Storage,
dstname: *const c_char,
) -> FS_Error
Back up the internal storage contents to a *.tar archive.
Arguments
storage - pointer to a storage API instance.
dstname - pointer to a zero-terminated string containing the archive file path.
Returns
FSE_OK if the storage was successfully backed up, any other error code on failure.